box_deref_transmute_locals

Function box_deref_transmute_locals 

fn box_deref_transmute_locals<'tcx>(
    tcx: TyCtxt<'tcx>,
    body: &Body<'tcx>,
) -> HashSet<Local>
Locals that hold the result of the compiler’s safe *box deref lowering (directly, or through copies and pointer casts). The compiler lowers *box to a raw-pointer deref of a pointer produced by casting the box’s inner field to a raw pointer, and that deref is safe by the Box invariant, so it is not a raw-pointer-deref checkpoint.