pub struct StaticMutAccessInfo<'tcx> {
pub block: BasicBlock,
pub static_def_id: DefId,
pub ty: Ty<'tcx>,
pub ptr_operand: Operand<'tcx>,
}Expand description
Metadata for a static mut access found in MIR.
Fields
block: BasicBlockBasic block containing the access.
static_def_id: DefIdThe mutable static being accessed.
ty: Ty<'tcx>The pointee type (i.e. the type of the static itself, T in static mut X: T).
ptr_operand: Operand<'tcx>The MIR operand holding the pointer to the static.